@@ -65,7 +65,7 @@ class cls():
 
         if device is None:
             device = "cuda" if torch.cuda.is_available() else "cpu"
-            logging.info("Use pytorch device: {}".format(device))
+        logging.info("Use pytorch device: {}".format(device))
         self._target_device = torch.device(device)
         self.model.to(self._target_device)
 
@@ -136,6 +136,7 @@ class cls():
             evaluator = None,
             epochs: int = 1,
             loss_fct = None,
+            category_weight = None,
             scheduler: str = 'WarmupLinear',
             warmup_proportion: float = 0.1,
             optimizer_type = 'AdamW',
@@ -190,7 +191,7 @@ class cls():
         optimizer = get_optimizer(model=self.model,optimizer_type=optimizer_type,weight_decay=weight_decay,optimizer_params=optimizer_params)
         scheduler = get_scheduler(optimizer, scheduler=scheduler, warmup_steps=warmup_steps, t_total=num_train_steps)
         if loss_fct is None:
-            loss_fct = nn.BCEWithLogitsLoss() if self.num_labels == 1 else nn.CrossEntropyLoss()
+            loss_fct = nn.BCEWithLogitsLoss(weight=category_weight) if self.num_labels == 1 else nn.CrossEntropyLoss(weight=category_weight)
 
         global_step=0
         skip_scheduler = False
